==> qt-creator-opensource-src-3.5.0.zip: qt-creator-opensource-src-3.5.0/src/plugins/qmldesigner/designercore/exceptions/invalidmetainfoexception.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "invalidmetainfoexception.h"

/*!
\class QmlDesigner::InvalidMetaInfoException
\ingroup CoreExceptions
\brief The InvalidMetaInfoException class provides an exception for invalid meta
info.

\see NodeMetaInfo PropertyMetaInfo MetaInfo
*/
namespace QmlDesigner {
/*!
    Constructs an exception. \a line uses the __LINE__ macro,
    \a function uses the __FUNCTION__ or the Q_FUNC_INFO macro, and \a file uses
    the __FILE__ macro.
*/
InvalidMetaInfoException::InvalidMetaInfoException(int line,
                                                           const QString &function,
                                                           const QString &file)
 : Exception(line, function, file)
{
    createWarning();
}

/*!
    Returns the type of this exception as a string.
*/
QString InvalidMetaInfoException::type() const
{
    return "InvalidMetaInfoException";
}

}

==> qt-creator-opensource-src-3.6.0.zip: qt-creator-opensource-src-3.6.0/src/plugins/qmldesigner/designercore/exceptions/invalidmetainfoexception.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPLv3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
****************************************************************************/

#include "invalidmetainfoexception.h"

/*!
\class QmlDesigner::InvalidMetaInfoException
\ingroup CoreExceptions
\brief The InvalidMetaInfoException class provides an exception for invalid meta
info.

\see NodeMetaInfo PropertyMetaInfo MetaInfo
*/
namespace QmlDesigner {
/*!
    Constructs an exception. \a line uses the __LINE__ macro,
    \a function uses the __FUNCTION__ or the Q_FUNC_INFO macro, and \a file uses
    the __FILE__ macro.
*/
InvalidMetaInfoException::InvalidMetaInfoException(int line,
                                                           const QByteArray &function,
                                                           const QByteArray &file)
 : Exception(line, function, file)
{
    createWarning();
}

/*!
    Returns the type of this exception as a string.
*/
QString InvalidMetaInfoException::type() const
{
    return QLatin1String("InvalidMetaInfoException");
}

}
